---
title: "Glossary"
---

```{python}
#| echo: false
#| output: asis
# Create the glossary table
import polars as pl

keep_items = ["data package", "data resource", "properties"]
glossary = (
    # This only works when building the website. Append `../`
    # to the path when running the code in the Quarto Notebook.
    pl.read_json('_extensions/seedcase-project/seedcase-theme/glossary.json')
        .filter(pl.col("item").is_in(keep_items))
        .rename(str.capitalize)
)

@pl.Config(
    tbl_formatting = "ASCII_MARKDOWN",
    tbl_hide_column_data_types = True,
    tbl_hide_dataframe_shape = True,
    tbl_width_chars=500,
    fmt_str_lengths=500
)
def as_md_table(data: pl.DataFrame) -> str:
    return str(data)
print(as_md_table(glossary))
```
